@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""Representation of a recording (handwritten data)."""
+"""Representation of a recording of on-line handwritten data. On-line means
+   that the pen trajectory is given (and not online as in 'Internet').
+"""
 
 import logging
 import json
@@ -14,13 +16,13 @@ class HandwrittenData(object):
     """Represents a handwritten symbol."""
     def __init__(self, raw_data_json, formula_id=None, raw_data_id=None,
                  formula_in_latex=None, wild_point_count=0,
-                 missing_line=0, user_id=0):
+                 missing_stroke=0, user_id=0):
         self.raw_data_json = raw_data_json
         self.formula_id = formula_id
         self.raw_data_id = raw_data_id
         self.formula_in_latex = formula_in_latex
         self.wild_point_count = wild_point_count
-        self.missing_line = missing_line
+        self.missing_stroke = missing_stroke
         self.user_id = user_id
         assert type(json.loads(self.raw_data_json)) is list, \
             "raw_data_json is not JSON: %r" % self.raw_data_json
@@ -28,7 +30,7 @@ class HandwrittenData(object):
             "The pointlist of formula_id %i is %s" % (self.formula_id,
                                                       self.get_pointlist())
         assert wild_point_count >= 0
-        assert missing_line >= 0
+        assert missing_stroke >= 0
 
     def get_pointlist(self):
         """Get a list of lists of tuples from JSON raw data string.
@@ -39,13 +41,13 @@ class HandwrittenData(object):
         """
         try:
             pointlist = json.loads(self.raw_data_json)
-        except Exception as inst:
+        except Exception as inst:  # pragma: no cover
             logging.debug("pointLineList: linelistP")
             logging.debug(self.raw_data_json)
             logging.debug("didn't work")
             raise inst
 
-        if len(pointlist) == 0:
+        if len(pointlist) == 0:  # pragma: no cover
             logging.warning("Pointlist was empty. Search for '" +
                             self.raw_data_json + "' in `wm_raw_draw_data`.")
         return pointlist
@@ -55,7 +57,7 @@ class HandwrittenData(object):
         pointlist = self.get_pointlist()
         for i in range(len(pointlist)):
             pointlist[i] = sorted(pointlist[i], key=lambda p: p['time'])
-        pointlist = sorted(pointlist, key=lambda line: line[0]['time'])
+        pointlist = sorted(pointlist, key=lambda stroke: stroke[0]['time'])
         return pointlist
 
     def set_pointlist(self, pointlist):
@@ -216,7 +218,3 @@ class HandwrittenData(object):
 
     def __str__(self):
         return self.__repr__()
-
-if __name__ == '__main__':
-    pass
-    #EXAMPLE.show()
