@@ -425,10 +425,10 @@ class Stroke_center(object):
         self.strokes = strokes
 
     def __repr__(self):
-        return "Center_of_mass"
+        return "Stroke_center"
 
     def __str__(self):
-        return "Center of mass"
+        return "Stroke center"
 
     def get_dimension(self):
         return self.strokes*2
@@ -450,7 +450,7 @@ class Stroke_center(object):
             feature_vector.append(numpy.mean(ys))
         while len(feature_vector) < self.get_dimension():
             feature_vector.append(0)
-        return [float(sum(xs))/len(xs), float(sum(ys))/len(ys)]
+        return feature_vector
 
 
 class Stroke_intersections(object):
